@@ -1,5 +1,5 @@
 var searchData=
 [
-  ['build_20instructions_0',['Build instructions',['../NanoVDB_HowToBuild.html',1,'']]],
+  ['build_20instructions_0',['Build instructions',['../NanoVDB_HowToBuild.html',1,'NanoVDB_MainPage']]],
   ['building_20openvdb_1',['Building OpenVDB',['../build.html',1,'openvdbax']]]
 ];
